@@ -1,6 +1,6 @@
 /* bluebox distributor
- * version 0.2 date 2006-11-29
- * Copyright (C) 2006 Stefan Schuermans <1stein@blinkenarea.org>
+ * version 0.3.1 date 2007-02-26
+ * Copyright (C) 2006-2007 Stefan Schuermans <1stein@blinkenarea.org>
  * Copyleft: GNU public license V2.0 - http://www.gnu.org/copyleft/gpl.html
  * a BlinkenArea project - http://www.blinkenarea.org/
  */
@@ -21,7 +21,7 @@ in_addr_t bd_in_listen_addr;
 in_port_t bd_in_listen_port;
 unsigned int bd_in_timeout;
 unsigned int bd_in_timeout_interval;
-double bd_map_gamma;
+double bd_map_base, bd_map_spread, bd_map_gamma;
 in_addr_t bd_out_bind_addr;
 in_port_t bd_out_bind_port;
 in_addr_t bd_out_ip_base, bd_out_ip_step;
@@ -29,16 +29,19 @@ in_port_t bd_out_dest_port;
 unsigned short bd_out_dev_cnt, bd_out_ser_cnt, bd_out_pix_cnt;
 unsigned char bd_out_command;
 unsigned char bd_out_turn_off;
+unsigned char bd_out_suffix;
+unsigned short bd_out_suffix_cnt;
 char bd_fmt_file[256];
 
 //buffers used to parse settings
 char bd_verbose_str[8];
 char bd_in_listen_str[32], bd_in_timeout_str[16], bd_in_timeout_interval_str[16];
-char bd_map_gamma_str[16];
+char bd_map_base_str[16], bd_map_spread_str[16], bd_map_gamma_str[16];
 char bd_out_bind_str[32];
 char bd_out_ip_base_str[16], bd_out_ip_step_str[16], bd_out_dest_port_str[16];
 char bd_out_dev_cnt_str[16], bd_out_ser_cnt_str[16], bd_out_pix_cnt_str[16];
-char bd_out_command_str[16], bd_out_turn_off_str[16];
+char bd_out_command_str[16], bd_out_turn_off_str[16], bd_out_suffix_str[16];
+char bd_out_suffix_cnt_str[16];
 
 //settings in troia_dist configuration file
 st_config_setting bd_settings[] = 
@@ -47,6 +50,8 @@ st_config_setting bd_settings[] =
   { "input", "listen", bd_in_listen_str, sizeof( bd_in_listen_str ), 0 },
   { "input", "timeout", bd_in_timeout_str, sizeof( bd_in_timeout_str ), 0 },
   { "input", "timeout_interval", bd_in_timeout_interval_str, sizeof( bd_in_timeout_interval_str ), 0 },
+  { "mapping", "base", bd_map_base_str, sizeof( bd_map_base_str ), 0 },
+  { "mapping", "spread", bd_map_spread_str, sizeof( bd_map_spread_str ), 0 },
   { "mapping", "gamma", bd_map_gamma_str, sizeof( bd_map_gamma_str ), 0 },
   { "output", "bind", bd_out_bind_str, sizeof( bd_out_bind_str ), 0 },
   { "output", "ip_base", bd_out_ip_base_str, sizeof( bd_out_ip_base_str ), 0 },
@@ -57,6 +62,8 @@ st_config_setting bd_settings[] =
   { "output", "pix_cnt", bd_out_pix_cnt_str, sizeof( bd_out_pix_cnt_str ), 0 },
   { "output", "command", bd_out_command_str, sizeof( bd_out_command_str ), 0 },
   { "output", "turn_off", bd_out_turn_off_str, sizeof( bd_out_turn_off_str ), 0 },
+  { "output", "suffix", bd_out_suffix_str, sizeof( bd_out_suffix_str ), 0 },
+  { "output", "suffix_cnt", bd_out_suffix_cnt_str, sizeof( bd_out_suffix_cnt_str ), 0 },
   { "format", "file", bd_fmt_file, sizeof( bd_fmt_file ), 0 },
 };
 
@@ -149,9 +156,25 @@ void bd_config_get( char * filename )
 
   //mapping
 
+  //parse base brighness value
+  if( sscanf( bd_map_base_str, "%lf", &bd_map_base ) != 1 ||
+      bd_map_base < 0.0 || bd_map_base > 1.0 )
+  {
+    printf( "config: mapping: error in format of base brightness value (\"%s\"), using 0.0\n", bd_map_base_str );
+    bd_map_base = 0.0;
+  }
+
+  //parse brighness spread value
+  if( sscanf( bd_map_spread_str, "%lf", &bd_map_spread ) != 1 ||
+      bd_map_spread < 0.01 || bd_map_spread > 100.0 )
+  {
+    printf( "config: mapping: error in format of brighness spread value (\"%s\"), using 1.0\n", bd_map_spread_str );
+    bd_map_spread = 1.0;
+  }
+
   //parse gamma correction value
   if( sscanf( bd_map_gamma_str, "%lf", &bd_map_gamma ) != 1 ||
-      bd_map_gamma <= 0.01 || bd_map_gamma > 100.0 )
+      bd_map_gamma < 0.01 || bd_map_gamma > 100.0 )
   {
     printf( "config: mapping: error in format of gamma correction value (\"%s\"), using 1.0\n", bd_map_gamma_str );
     bd_map_gamma = 1.0;
@@ -281,7 +304,31 @@ void bd_config_get( char * filename )
   if( bd_out_turn_off < 0x80 )
   {
     printf( "config: output: invalid turn_off byte (0x%02X), using 0x80\n", bd_out_turn_off );
-    bd_out_turn_off = 0x82;
+    bd_out_turn_off = 0x80;
+  }
+
+  //convert suffix byte into number
+  if( sscanf( bd_out_suffix_str, "%hhi", &bd_out_suffix ) != 1 )
+  {
+    printf( "config: output: error in format of suffix byte (\"%s\"), using 0x55\n", bd_out_suffix_str );
+    bd_out_suffix = 0x55;
+  }
+  if( bd_out_suffix >= 0x80 )
+  {
+    printf( "config: output: invalid suffix byte (0x%02X), using 0x55\n", bd_out_suffix );
+    bd_out_suffix = 0x55;
+  }
+
+  //convert suffix count into number
+  if( sscanf( bd_out_suffix_cnt_str, "%hi", &bd_out_suffix_cnt ) != 1 )
+  {
+    printf( "config: output: error in format of suffix count (\"%s\"), using 1\n", bd_out_suffix_cnt_str );
+    bd_out_suffix_cnt = 1;
+  }
+  if( bd_out_suffix_cnt > 16 )
+  {
+    printf( "config: output: invalid suffix count (%d), using 1\n", bd_out_suffix_cnt );
+    bd_out_suffix_cnt = 1;
   }
 
   //format
