@@ -1,6 +1,6 @@
 /* bluebox distributor
- * version 0.2 date 2006-11-29
- * Copyright (C) 2006 Stefan Schuermans <1stein@blinkenarea.org>
+ * version 0.3.1 date 2007-02-26
+ * Copyright (C) 2006-2007 Stefan Schuermans <1stein@blinkenarea.org>
  * Copyleft: GNU public license V2.0 - http://www.gnu.org/copyleft/gpl.html
  * a BlinkenArea project - http://www.blinkenarea.org/
  */
@@ -16,7 +16,7 @@ extern in_addr_t bd_in_listen_addr;
 extern in_port_t bd_in_listen_port;
 extern unsigned int bd_in_timeout;
 extern unsigned int bd_in_timeout_interval;
-extern double bd_map_gamma;
+extern double bd_map_base, bd_map_spread, bd_map_gamma;
 extern in_addr_t bd_out_bind_addr;
 extern in_port_t bd_out_bind_port;
 extern in_addr_t bd_out_ip_base, bd_out_ip_step;
@@ -24,6 +24,8 @@ extern in_port_t bd_out_dest_port;
 extern unsigned short bd_out_dev_cnt, bd_out_ser_cnt, bd_out_pix_cnt;
 extern unsigned char bd_out_command;
 extern unsigned char bd_out_turn_off;
+extern unsigned char bd_out_suffix;
+extern unsigned short bd_out_suffix_cnt;
 extern char bd_fmt_file[];
 
 //get troia_dist configuration from configuration file
