@@ -1,6 +1,6 @@
 /* bluebox distributor
- * version 0.2 date 2006-11-29
- * Copyright (C) 2006 Stefan Schuermans <1stein@blinkenarea.org>
+ * version 0.3.1 date 2007-02-26
+ * Copyright (C) 2006-2007 Stefan Schuermans <1stein@blinkenarea.org>
  * Copyleft: GNU public license V2.0 - http://www.gnu.org/copyleft/gpl.html
  * a BlinkenArea project - http://www.blinkenarea.org/
  */
@@ -57,7 +57,7 @@ int main( int arg_cnt, char * * args )
   fd_set fdset;
   unsigned int last_recv, cur;
   struct timeval timeout;
-  unsigned short dev_no, ser_no, pix_no;
+  unsigned short dev_no, ser_no, pix_no, suffix_no;
   int cnt, len, addr_len, i, y, x;
   unsigned char * ptr;
   in_addr_t in_addr;
@@ -66,8 +66,8 @@ int main( int arg_cnt, char * * args )
   //print message
   printf( "\n"
           "bluebox distributor\n"
-          "version 0.2 date 2006-11-29\n"
-          "Copyright (C) 2006 Stefan Schuermans <1stein@blinkenarea.org>\n"
+          "version 0.3.1 date 2007-02-26\n"
+          "Copyright (C) 2006-2007 Stefan Schuermans <1stein@blinkenarea.org>\n"
           "Copyleft: GNU public license V2.0 - http://www.gnu.org/copyleft/gpl.html\n"
           "a BlinkenArea project - http://www.blinkenarea.org/\n"
           "\n" );
@@ -97,7 +97,7 @@ int main( int arg_cnt, char * * args )
   }
 
   //allocate output buffers
-  out_buffer_len = (1 + bd_out_pix_cnt) * bd_out_ser_cnt; //length of output buffer for 1 device
+  out_buffer_len = (1 + bd_out_pix_cnt + bd_out_suffix_cnt) * bd_out_ser_cnt; //length of output buffer for 1 device
   len = bd_out_dev_cnt * sizeof( unsigned char * ) //dev_cnt pointers to 1D arrays
       + bd_out_dev_cnt * out_buffer_len; //dev_cnt output buffers
   p_out_buffers = (unsigned char * *)malloc( len );
@@ -115,13 +115,20 @@ int main( int arg_cnt, char * * args )
     ptr += out_buffer_len;
   }
   //initialize data in output buffers
-  for( dev_no = 0; dev_no < bd_out_dev_cnt; dev_no++ )
-    for( pix_no = 0, i = 0; pix_no < 1 + bd_out_pix_cnt; pix_no++ )
-      for( ser_no = 0; ser_no < bd_out_ser_cnt; ser_no++, i++ )
-        p_out_buffers[dev_no][i] = pix_no == 0 ? bd_out_command : 0x00; //use command byte and pixel values 0x00 by default
+  for( dev_no = 0; dev_no < bd_out_dev_cnt; dev_no++ ) {
+    i = 0;
+    for( ser_no = 0; ser_no < bd_out_ser_cnt; ser_no++ ) //command byte
+      p_out_buffers[dev_no][i++] = bd_out_command;
+    for( pix_no = 0; pix_no < bd_out_pix_cnt; pix_no++ ) //pixel values
+      for( ser_no = 0; ser_no < bd_out_ser_cnt; ser_no++ )
+        p_out_buffers[dev_no][i++] = 0x00;
+    for( suffix_no = 0; suffix_no < bd_out_suffix_cnt; suffix_no++ ) //suffix bytes
+      for( ser_no = 0; ser_no < bd_out_ser_cnt; ser_no++ )
+        p_out_buffers[dev_no][i++] = bd_out_suffix;
+  }
 
   //allocate turn off buffers
-  turn_off_buffer_len = bd_out_ser_cnt; // length of turn off buffer for 1 device
+  turn_off_buffer_len = (1 + bd_out_suffix_cnt) * bd_out_ser_cnt; // length of turn off buffer for 1 device
   len = bd_out_dev_cnt * sizeof( unsigned char * ) //dev_cnt pointers to 1D arrays
       + bd_out_dev_cnt * turn_off_buffer_len; //dev_cnt turn off buffers
   p_turn_off_buffers = (unsigned char * *)malloc( len );
@@ -140,9 +147,14 @@ int main( int arg_cnt, char * * args )
     ptr += turn_off_buffer_len;
   }
   //initialize data in turn off buffers
-  for( dev_no = 0; dev_no < bd_out_dev_cnt; dev_no++ )
+  for( dev_no = 0; dev_no < bd_out_dev_cnt; dev_no++ ) {
+    i = 0;
     for( ser_no = 0; ser_no < bd_out_ser_cnt; ser_no++ )
-      p_turn_off_buffers[dev_no][ser_no] = bd_out_turn_off; //use turn off byte
+      p_turn_off_buffers[dev_no][i++] = bd_out_turn_off; //turn off byte
+    for( suffix_no = 0; suffix_no < bd_out_suffix_cnt; suffix_no++ ) //suffix bytes
+      for( ser_no = 0; ser_no < bd_out_ser_cnt; ser_no++ )
+        p_turn_off_buffers[dev_no][i++] = bd_out_suffix;
+  }
 
   //generate format from format file
   p_bd_fmt = bd_fmt_load( bd_fmt_file );
@@ -299,8 +311,12 @@ int main( int arg_cnt, char * * args )
     ntohs( addr.sin_port ) );
 
   //initialize mapping from gayscale values to PWM values
-  printf( "grayscale value to PWM value mapping: gamma=%f\n", bd_map_gamma );
-  gray2pwm_init( bd_map_gamma );
+  printf( "grayscale value to PWM value mapping:\n"
+          "  base=%f\n"
+          "  spread=%f\n"
+          "  gamma=%f\n",
+          bd_map_base, bd_map_spread, bd_map_gamma );
+  gray2pwm_init( bd_map_base, bd_map_spread, bd_map_gamma );
 
   //install signal handler to end program
   signal( SIGTERM, end_signal );
@@ -359,11 +375,14 @@ int main( int arg_cnt, char * * args )
     FD_ZERO( &fdset );
     FD_SET( in_sock_fd, &fdset );
     timeout.tv_sec = 0;
-    if( cur - last_recv >= bd_in_timeout * 1000 )
+    unsigned int wait_rest = cur - last_recv;
+    if( wait_rest >= bd_in_timeout * 1000 || wait_rest >= bd_in_timeout_interval )
       timeout.tv_usec = 0;
     else
     {
-      unsigned int timeout_ms = bd_in_timeout * 1000 - (cur - last_recv);
+      unsigned int timeout_ms_to = bd_in_timeout * 1000 - wait_rest;
+      unsigned int timeout_ms_to_i = bd_in_timeout_interval * 1000 - wait_rest;
+      unsigned int timeout_ms = timeout_ms_to < timeout_ms_to_i ? timeout_ms_to : timeout_ms_to_i;
       timeout.tv_usec = timeout_ms < 100 ? timeout_ms * 1000 : 100000;
     }
     cnt = select( in_sock_fd + 1, &fdset, NULL, NULL, &timeout );
