@@ -1,6 +1,6 @@
 /* bluebox distributor
- * version 0.2 date 2006-11-29
- * Copyright (C) 2006 Stefan Schuermans <1stein@blinkenarea.org>
+ * version 0.3.1 date 2007-02-26
+ * Copyright (C) 2006-2007 Stefan Schuermans <1stein@blinkenarea.org>
  * Copyleft: GNU public license V2.0 - http://www.gnu.org/copyleft/gpl.html
  * a BlinkenArea project - http://www.blinkenarea.org/
  */
@@ -21,14 +21,16 @@
 unsigned char gray2pwm[0x100];
 
 //initialize mapping from gayscale values to PWM values
-void gray2pwm_init( double gamma )
+void gray2pwm_init( double base, double spread, double gamma )
 {
   int i;
   for( i = 0; i < 0x100; i++ )
   {
-    double x = (double)i / (double)0xFF; // 0x00 ... 0xFF ---> 0.0 ... 1.0
-    double y = pow( x, gamma ); // gamma correction
-    gray2pwm[i] = (unsigned char)((double)0x7F * y + 0.5); // 0.0 ... 0.1 ---> 0x00 .. 0x7F
+    double val = (double)i / (double)0xFF; // 0x00 ... 0xFF ---> 0.0 ... 1.0
+    val = val * spread + base; // base brightness and brighness spread
+    if( val < 0.0 ) val = 0.0; if( val > 1.0 ) val = 1.0; // clamp value to valid range: 0.0 ... 1.0
+    val = pow( val, gamma ); // gamma correction
+    gray2pwm[i] = (unsigned char)((double)0x7F * val + 0.5); // 0.0 ... 0.1 ---> 0x00 .. 0x7F
   }
 }
 
