@@ -1,6 +1,6 @@
 /* bluebox distributor
- * version 0.2 date 2006-11-29
- * Copyright (C) 2006 Stefan Schuermans <1stein@blinkenarea.org>
+ * version 0.3.1 date 2007-02-26
+ * Copyright (C) 2006-2007 Stefan Schuermans <1stein@blinkenarea.org>
  * Copyleft: GNU public license V2.0 - http://www.gnu.org/copyleft/gpl.html
  * a BlinkenArea project - http://www.blinkenarea.org/
  */
@@ -11,11 +11,11 @@
 #include "bd_fmt.h"
 
 //initialize mapping from gayscale values to pwm values
-void gray2pwm_init( double gamma );
+void gray2pwm_init( double base, double spread, double gamma );
 
 //processs a recevied datagram
 //p_out_buffers must point to an array of dev_cnt output buffers
-//  every output buffer must be of size (1 + pix_cnt) * ser_cnt
+//  every output buffer must be at least of size (1 + pix_cnt) * ser_cnt
 //  pixels start at offset 1 in output buffers
 //  every pixel in output buffer is encoded with 7 bit (i.e. 0..127)
 //returns 1 on success, 0 on error
